@@ -7,8 +7,10 @@ inverseCDF <- function(p, CDF, ...) {
     stop("'log.p' not yet implemented (ie, always FALSE)")
   if(!is.null(list(...)$lower.tail))
     stop("'lower.tail' not yet implemented (ie, always TRUE)")
-  if(p < 0 || p > 1)
+  if(any(p < 0 | p > 1))
     stop("'p' must be a probability in the interval (0, 1)")
+  p <-  pmin(pmax(p, 1e-6), 1 - 1e-6) # Fix values too close to 0 or 1
+
   too <- function(x, p, ...) CDF(x, ...) - p
   q <- numeric(length(p))
   for(i in seq_along(p))
